pub struct ContextGuard { /* private fields */ }Available on crate feature
std only.Expand description
RAII guard that removes a context slot when dropped.
Returned by with_field, with_trace_id, and
with_request_id. Drop the guard at the end of the scope where
the context applies. Dropping guards out-of-order is supported.