warn

Macro warn 

macro_rules! warn {
    ($logger:expr, $($rest:tt)*) => { ... };
}
Available on crate feature std only.
Emit a crate::Level::Warn record.

Despite the name colliding with the warn attribute, this macro works in expression position the same way log::warn! does in the upstream log crate.