pub struct FilterRule {
pub target: String,
pub level: Level,
}Available on crate feature
std only.Expand description
One rule in a Filter.
A rule pairs a target prefix with a minimum severity. A record is
admitted by a rule when its level is >= the rule’s level.
Fields
target: StringTarget prefix the rule applies to.
level: LevelMinimum severity allowed through.
Implementations